<?php
namespace SaaslandCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use WP_Query;


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}



/**
 * Text Typing Effect
 *
 * Elementor widget for text typing effect.
 *
 * @since 1.7.0
 */
class Saasland_blog_grid extends Widget_Base {

    public function get_name() {
        return 'saasland_blog_grid';
    }

    public function get_title() {
        return __( 'Blog Grid', 'saasland-core' );
    }

    public function get_icon() {
        return ' eicon-post';
    }

    public function get_categories() {
        return [ 'saasland-elements' ];
    }

    protected function _register_controls() {

        // ---------------------------------- Filter Options ------------------------
        $this->start_controls_section(
            'filter', [
                'label' => __( 'Blog Settings', 'saasland-core' ),
            ]
        );

        $this->add_control(
            'show_posts_count', [
                'label' => esc_html__( 'Show Posts Count', 'saasland-core' ),
                'type' => Controls_Manager::NUMBER,
                'default' => 8
            ]
        );

        $this->add_control(
            'order', [
                'label' => esc_html__( 'Order', 'saasland-core' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'ASC' => 'ASC',
                    'DESC' => 'DESC'
                ],
                'default' => 'ASC'
            ]
        );

        $this->add_control(
            'excerpt_limit_word', [
                'label' => esc_html__( 'Excerpt Limit Word', 'saasland-core' ),
                'type' => Controls_Manager::NUMBER,
                'default' => 8
            ]
        );

        $this->add_control(
            'read_more', [
                'label' => esc_html__( 'Read More Label', 'saasland-core' ),
                'type' => Controls_Manager::TEXT,
                'default' => 'Read More'
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {

        $settings = $this->get_settings();

        global $wp_query;
        global $paged;
        $temp = $wp_query;
        $wp_query = null;
        $wp_query = new WP_Query();
        $wp_query->query('showposts='.$settings['show_posts_count'].'&post_type=post'.'&paged='.$paged);
        $excerpt_limit_word = isset($settings['excerpt_limit_word']) ? $settings['excerpt_limit_word'] : 14;
        ?>
        <section class="blog_area_two">
            <div class="blog_grid_info">
                <div class="container">
                    <div class="row">
                    <?php
                    while($wp_query->have_posts()) : $wp_query->the_post();
                        ?>
                        <div <?php post_class('col-lg-6') ?>>
                            <div class="blog_list_item blog_list_item_two">
                                <?php
                                if(has_post_thumbnail()) : ?>
                                    <div class="post_date">
                                        <h2> <?php the_time('d') ?> <span> <?php the_time('M') ?> </span></h2>
                                    </div>
                                <?php endif; ?>

                                <a href="<?php the_permalink() ?>">
                                    <?php the_post_thumbnail('saasland_370x300', array('class' => 'img-fluid')) ?>
                                </a>

                                <div class="blog_content">

                                    <a href="<?php the_permalink() ?>">
                                        <h5 class="blog_title" title="<?php the_title_attribute() ?>"> <?php saasland_limit_latter(get_the_title(), 48); ?> </h5>
                                    </a>

                                    <p> <?php echo strip_shortcodes(wp_trim_words(get_the_content(), $excerpt_limit_word)) ?> </p>

                                    <div class="post-info-bottom">
                                        <a href="<?php the_permalink() ?>" class="learn_btn_two">
                                            <?php echo esc_html($settings['read_more']) ?>
                                            <i class="arrow_right"></i>
                                        </a>
                                        <?php if(function_exists('saasland_comment_count')) : ?>
                                            <a class="post-info-comments" href="<?php the_permalink() ?>#comments">
                                                <i class="icon_comment_alt" aria-hidden="true"></i>
                                                <span> <?php saasland_comment_count(get_the_ID()) ?> </span>
                                            </a>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <?php
                    endwhile;
                    wp_reset_query();
                    ?>
                    <?php
                    if(function_exists('saasland_pagination')) {
                        saasland_pagination();
                    }
                    ?>
                    </div>
                </div>
            </div>

        </section>
        <?php
    }
}